==> apache-beam-2.53.0-source-release.zip: beam-2.53.0/learning/tour-of-beam/learning-content/common-transforms/filter/go-example/main.go <==
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// beam-playground:
//   name: Filter
//   description: Filter example.
//   multifile: false
//   context_line: 38
//   categories:
//     - Quickstart
//   complexity: BASIC
//   tags:
//     - hellobeam

package main

import (
    "context"
    "github.com/apache/beam/sdks/v2/go/pkg/beam"
    "github.com/apache/beam/sdks/v2/go/pkg/beam/log"
    "github.com/apache/beam/sdks/v2/go/pkg/beam/x/beamx"
    "github.com/apache/beam/sdks/v2/go/pkg/beam/x/debug"
    "github.com/apache/beam/sdks/v2/go/pkg/beam/transforms/filter"
)

func main() {
    ctx := context.Background()

    p, s := beam.NewPipelineWithRoot()

    // List of elements
    input := beam.Create(s, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10)

    // The [input] filtered with the applyTransform()
    output := applyTransform(s, input)

    debug.Printf(s, "PCollection filtered value: %v", output)

    err := beamx.Run(ctx, p)

    if err != nil {
        log.Exitf(context.Background(), "Failed to execute job: %v", err)
    }
}

// The method filters the collection so that the numbers are even
func applyTransform(s beam.Scope, input beam.PCollection) beam.PCollection {
    return filter.Exclude(s, input, func(element int) bool {
        return element % 2 == 1
    })
}

==> apache-beam-2.57.0-source-release.zip: beam-2.57.0/learning/tour-of-beam/learning-content/common-transforms/filter/go-example/main.go <==
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//    http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// beam-playground:
//   name: Filter
//   description: Filter example.
//   multifile: false
//   context_line: 38
//   categories:
//     - Quickstart
//   complexity: BASIC
//   tags:
//     - hellobeam

package main

import (
	"context"

	"github.com/apache/beam/sdks/v2/go/pkg/beam"
	"github.com/apache/beam/sdks/v2/go/pkg/beam/log"
	"github.com/apache/beam/sdks/v2/go/pkg/beam/transforms/filter"
	"github.com/apache/beam/sdks/v2/go/pkg/beam/x/beamx"
	"github.com/apache/beam/sdks/v2/go/pkg/beam/x/debug"
)

func main() {
	ctx := context.Background()
	beam.Init()

	p, s := beam.NewPipelineWithRoot()

	// List of elements
	input := beam.Create(s, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10)

	// The [input] filtered with the applyTransform()
	output := applyTransform(s, input)

	debug.Printf(s, "PCollection filtered value: %v", output)

	err := beamx.Run(ctx, p)

	if err != nil {
		log.Exitf(ctx, "Failed to execute job: %v", err)
	}
}

// The method filters the collection so that the numbers are even
func applyTransform(s beam.Scope, input beam.PCollection) beam.PCollection {
	return filter.Exclude(s, input, func(element int) bool {
		return element%2 == 1
	})
}
